@@ -47,12 +47,15 @@ class CsvData:
 class DataTypeId:
     karrusrd = 'karrusrd'
     metropme = 'metropme'
+    zonepoints = 'zonepoints'
     roads = 'roads'
     tomtomfcd = 'tomtomfcd'
     zones = 'zones'
 
+    dataquality = 'dataquality'
     datapoints = 'datapoints'
     mappingroadsdatapoints = 'mappingroadsdatapoints'
+    traveltimes = 'traveltimes'
 
 
 class NetworkObjId:
@@ -69,3 +72,7 @@ class NetworkObjId:
     roadszonesmap = 'roadszonesmap'
     voronoiroadmap = 'voronoiroadmap'
     zonesdatamap = 'zonesdatamap'
+
+
+INDICATORS_DATA_TYPES = (DataTypeId.karrusrd, DataTypeId.metropme, DataTypeId.tomtomfcd, DataTypeId.roads,
+                         DataTypeId.zones)
